@@ -13,7 +13,7 @@ def length(a: Numeric):
 
 
 @dispatch
-def expand_dims(a: Numeric, axis: Int = 0):
+def _expand_dims(a: Numeric, axis: Int = 0):
     return jnp.expand_dims(a, axis=axis)
 
 
@@ -43,7 +43,7 @@ def stack(*elements: Numeric, axis: Int = 0):
 
 
 @dispatch
-def unstack(a: Numeric, axis: Int = 0):
+def _unstack(a: Numeric, axis: Int = 0):
     out = jnp.split(a, jnp.arange(1, a.shape[axis]), axis)
     return [x.squeeze(axis=axis) for x in out]
 
