@@ -13,6 +13,7 @@ __all__ = [
     "matmul",
     "mm",
     "dot",
+    "einsum",
     "kron",
     "trace",
     "svd",
@@ -102,7 +103,21 @@ dot = matmul  #: Shorthand for `matmul`.
 
 
 @dispatch
-@abstract(promote=None)
+@abstract(promote_from=1)
+def einsum(equation: str, *elements: Numeric):  # pragma: no cover
+    """Tensor contraction via Einstein summation.
+
+    Args:
+        equation (str): Equation.
+        *elements (tensor): Tensors to contract.
+
+    Returns:
+        tensor: Contraction.
+    """
+
+
+@dispatch
+@abstract()
 def trace(a: Numeric, axis1: Int = -2, axis2: Int = -1):  # pragma: no cover
     """Compute the trace of a tensor.
 
@@ -184,7 +199,7 @@ def svd(a: Numeric, compute_uv: bool = True):  # pragma: no cover
             `True`.
 
     Returns:
-        tuple: `(U, S, V)` is `compute_uv` is `True` and just `S` otherwise.
+        tuple: `(U, S, V)` if `compute_uv` is `True` and just `S` otherwise.
     """
 
 
@@ -198,7 +213,7 @@ def eig(a: Numeric, compute_eigvecs: bool = True):  # pragma: no cover
         compute_eigvecs (bool, optional): Also compute eigenvectors. Defaults to `True`.
 
     Returns:
-        tuple: `(U, S, V)` is `compute_uv` is `True` and just `S` otherwise.
+        tuple: `(S, V)` if `compute_eigvecs` is `True` and just `S` otherwise.
     """
 
 
