@@ -107,6 +107,21 @@ def identity(a: Numeric):
     return 1 * a
 
 
+@dispatch
+def round(a: Numeric):
+    return torch.round(a)
+
+
+@dispatch
+def floor(a: Numeric):
+    return torch.floor(a)
+
+
+@dispatch
+def ceil(a: Numeric):
+    return torch.ceil(a)
+
+
 @dispatch
 def negative(a: Numeric):
     return torch.neg(a)
