@@ -105,20 +105,26 @@ def test_device_and_to_active_device(check_lazy_shapes):
     ],
 )
 def test_on_device(f, t, check_lazy_shapes):
+    f_t = f(t)  # Contruct on current and existing device.
+
+    # Set the active device to something else.
+    B.ActiveDevice.active_name = "previous"
+
     # Check that explicit allocation on CPU works.
     with B.on_device("cpu"):
-        f(t)
+        assert B.device(f(t)) == B.device(f_t)
+
     # Also test inferring the device from a tensor.
-    with B.on_device(f(t)):
-        f(t)
+    with B.on_device(f_t):
+        assert B.device(f(t)) == B.device(f_t)
 
     # Check that allocation on a non-existing device breaks.
     with pytest.raises(Exception):
         with B.on_device("magic-device"):
             f(t)
 
-    # Reset the active device. This is still set to "magic-device" due to the above
-    # test.
+    # Check that the active device is reset again.
+    assert B.ActiveDevice.active_name == "previous"
     B.ActiveDevice.active_name = None
 
 
@@ -313,6 +319,9 @@ def test_unary_complex(f, check_lazy_shapes):
     "f",
     [
         B.identity,
+        B.round,
+        B.floor,
+        B.ceil,
         B.negative,
         B.abs,
         B.sign,
